Skip to contents

Displays a kernel density estimate of the posterior mean person abilities (\(\hat{\theta}^{PM}\)). Useful for assessing the shape of the estimated latent trait distribution. Requires ggplot2.

Usage

dpmirt_plot_density(fit, ...)

Arguments

fit

A dpmirt_fit object from dpmirt.

...

Currently unused.

Value

A ggplot object.

Examples

if (FALSE) { # \dontrun{
sim <- dpmirt_simulate(200, 20, model = "rasch", seed = 42)
fit <- dpmirt(sim$response, model = "rasch", prior = "normal",
              niter = 5000, nburnin = 1000, seed = 123)
dpmirt_plot_density(fit)
} # }